referrerpolicy=no-referrer-when-downgrade

ParachainHostFunctions

Type Alias ParachainHostFunctions 

pub type ParachainHostFunctions = (HostFunctions, SubstrateHostFunctions, HostFunctionsRfc163);
Host functions that should be used in parachain nodes.

Contains the standard substrate host functions, as well as a host function to enable PoV-reclaim on parachain nodes.